<?php

declare(strict_types=1);

namespace App\Utils;

use Symfony\Component\Finder\Finder;
use Symfony\Component\Finder\SplFileInfo;

class MediaFunction{

    public function findFiles(string $base, string $path,$sortBy = null,$orderBy = null): Finder
    {

        $fullpath = $base. DIRECTORY_SEPARATOR .$path;
        $finder = new Finder();

        if($orderBy == 'desc'){
             $finder->reverseSorting();
        }

        switch ($sortBy) {
            case 'name':
                $finder->in($fullpath)->depth('== 0')->files()->sort(function (SplFileInfo $a, SplFileInfo $b) {
                    return strcmp(mb_strtolower($b->getFilename()), mb_strtolower($a->getFilename()));
                });
                break;
            case 'date':
                $finder->in($fullpath)->depth('== 0')->files()->sortByModifiedTime();
                break;
            case 'size':
                $finder->in($fullpath)->depth('== 0')->files()->sort(function (\SplFileInfo $a, \SplFileInfo $b) {
                    return $a->getSize() - $b->getSize();
                });
                break;
            default:
                $finder->in($fullpath)->depth('== 0')->files()->sort(function (SplFileInfo $a, SplFileInfo $b) {
                    return strcmp(mb_strtolower($b->getFilename()), mb_strtolower($a->getFilename()));
                });
                break;
        }

        return $finder;
    }

    public function findFolders(string $base, string $path,$sortBy = null,$orderBy = null): Finder
    {
        $fullpath = $base. DIRECTORY_SEPARATOR .$path;

        $finder = new Finder();
        if($orderBy == 'desc'){
            $finder->reverseSorting();
        }

        switch ($sortBy) {
            case 'name':
                $finder->in($fullpath)->depth('== 0')->directories()->sort(function (SplFileInfo $a, SplFileInfo $b) {
                    return strcmp(mb_strtolower($b->getFilename()), mb_strtolower($a->getFilename()));
                });
                break;
            case 'date':
                $finder->in($fullpath)->depth('== 0')->directories()->sortByModifiedTime();
                break;
            case 'size':
                $finder->in($fullpath)->depth('== 0')->directories()->sort(function (\SplFileInfo $a, \SplFileInfo $b) {
                    return $a->getSize() - $b->getSize();
                });
                break;
            default:
                $finder->in($fullpath)->depth('== 0')->directories()->sort(function (SplFileInfo $a, SplFileInfo $b) {
                    return strcmp(mb_strtolower($b->getFilename()), mb_strtolower($a->getFilename()));
                });
                break;
        }

        return $finder;
    }

    public static function endsWith(string $subject, string $search, bool $caseSensitive = true): bool
    {
        if (! $caseSensitive) {
            $subject = mb_strtolower($subject);
            $search = mb_strtolower($search);
        }

        return $search === '' || mb_substr($subject, -mb_strlen($search)) === $search;
    }


    public static function startsWith(string $subject, string $search, bool $caseSensitive = true): bool
    {
        if (! $caseSensitive) {
            $subject = mb_strtolower($subject);
            $search = mb_strtolower($search);
        }

        return $search === '' || mb_substr($subject, 0, mb_strlen($search)) === $search;
    }

    
    public function isImage(string $guessExtension): bool
    {
        return in_array($guessExtension, ['gif', 'png', 'jpg', 'jpeg', 'svg', 'webp', 'avif'], true);
    }




}